=======
Credits
=======

Contributors
------------

* Ricarda Beckmann <ricarda.beckmann@astro.ox.ac.uk>
* Yi-Hao Chen <ychen@astro.wisc.edu>
* Nathan Goldbaum <ngoldbau@illinois.edu>
* David Hannasch <David.A.Hannasch@gmail.com>
* Cameron Hummels <chummels@gmail.com>
* Suoqing Ji <jisuoqing@gmail.com>
* Kacper Kowalik <xarthisius.kk@gmail.com>
* Andrew Myers <atmyers2@gmail.com>
* Sam Skillman <samskillman@gmail.com>
* Britton Smith <brittonsmith@gmail.com>
* Josh Soref
* Ben Thompson
* Matthew Turk <matthewturk@gmail.com>
* John ZuHone <jzuhone@gmail.com>

